/*
 * "$Id: topcl.h,v 1.4 93/12/05 10:44:08 mike Exp Locker: mike $"
 *
 * Common header file for TOPCL, an SGI image to PCL converter.
 *
 * Copyright (c) 1993 Easy Software Products
 *                    P.O. Box 256
 *                    Park Hall, MD  20667
 *                    Attn: Michael Sweet (dodgecolt@delphi.com)
 *
 * This file is part of TOPCL.
 *
 * TOPCL is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
 * to anyone for the consequences of using it or for whether it serves any
 * particular purpose or works at all, unless he says so in writing.  Refer
 * to the TOPCL General Public License for full details.
 *
 * Everyone is granted permission to copy, modify and redistribute
 * TOPCL, but only under the conditions described in the TOPCL
 * General Public License.  A copy of this license is supposed to have been
 * given to you along with TOPCL so you can know your rights and
 * responsibilities.  It should be in a file named COPYING.  Among other
 * things, the copyright notice and this notice must be preserved on all
 * copies.
 *
 * Revision History:
 *
 *  $Log:	topcl.h,v $
 * Revision 1.4  93/12/05  10:44:08  mike
 * Adjusted inkjet page lengths by 0.25 inches (180 decipoints) to reflect
 *   unusable bottom of page.
 * Updated documentation for v1.1 release.
 * 
 * Revision 1.3  93/12/05  02:25:26  mike
 * Added mode 9 compression definitions.
 * 
 * Revision 1.2  93/06/10  22:34:24  mike
 * Cleaned up for version 1.0 release.
 * 
 * Revision 1.1  93/05/24  19:42:43  mike
 * Initial revision
 * 
 *
 */

#ifndef _TOPCL_H_
# define _TOPCL_H_

/*
 * Include necessary headers.
 */

# include <stdio.h>      /* Standard library stuff... */
# include <stdlib.h>
# include <string.h>
# include <errno.h>
# include <sys/types.h>
# include <malloc.h>     /* Fast malloc() library... */

# include <gl/image.h>   /* SGI image file definitions */

# ifndef FALSE
#  define FALSE 0
#  define TRUE  (!FALSE)
# endif /* !FALSE */


/*
 * Image structures...
 */

                         /* --- RGB Pixel --- */
typedef unsigned char RGB_PIXEL[3];

typedef struct           /* --- RGB Image --- */
 {
  int           width,   /* Width of image in pixels */
                height;  /* Height of image in pixels */
  RGB_PIXEL     *pixels; /* Pixel data, left-to-right, bottom-to-top */
 } RGB_IMAGE;

/*
 * Printer model structure...
 */

typedef struct
 {
  int model,             /* Printer model */
      type,              /* B&W or color printer */
      mode,              /* Type of compression supported */
      dpi,               /* Maximum resolution supported */
      copies,            /* TRUE if printer supports multiple copies */
      letter_width,      /* Letter-size paper width (decipoints) */
      letter_height,     /* Letter-size paper height (decipoints) */
      legal_width,       /* Legal-size paper width (decipoints) */
      legal_height,      /* Legal-size paper height (decipoints) */
      exec_width,        /* Executive-size paper width (decipoints) */
      exec_height,       /* Executive-size paper height (decipoints) */
      a4_width,          /* A4-size paper width (decipoints) */
      a4_height;         /* A4-size paper height (decipoints) */
 } PRINTER;


/*
 * Constants...
 */

# define PCL_AUTO           -1   /* Automatically set to default value */

# define PCL_BW             2    /* Black-and-white output */
# define PCL_COLOR          0    /* Color output */

# define PCL_MODE0          0    /* Non-compressed output */
# define PCL_MODE1          1    /* RLE compressed output (skipped) */
# define PCL_MODE2          2    /* TIFF compressed output */
# define PCL_MODE3          3    /* Delta-row compressed output */
# define PCL_MODE9          9    /* DeskJet compressed output */

# define PCL_75DPI          75   /* 75 dots-per-inch */
# define PCL_100DPI         100  /* 100 dots-per-inch */
# define PCL_150DPI         150  /* 150 dots-per-inch */
# define PCL_300DPI         300  /* 300 dots-per-inch (requires 1 Mb RAM) */
# define PCL_600DPI         600  /* 600 dots-per-inch (requires 4 Mb RAM) */

# define PCL_PAPER          0    /* Paper media */
# define PCL_TRANSPARENCY   1    /* Transparency media */

# define PCL_PORTRAIT       0    /* Portrait orientation */
# define PCL_LANDSCAPE      1    /* Lanscape orientation */

# define PCL_FLIP_NONE      0    /* Flip no axis */
# define PCL_FLIP_X         1    /* Flip X axis */
# define PCL_FLIP_Y         2    /* Flip Y axis */
# define PCL_FLIP_XY        3    /* Flip X & Y axis */

# define PCL_DEFAULT_TRAY   0    /* Get media from default tray */
# define PCL_UPPER_TRAY     1    /* Get media from upper tray */
# define PCL_LOWER_TRAY     4    /* Get media from lower tray */
# define PCL_MANUAL_FEED    2    /* Get media from manual feed */

# define PCL_EXECUTIVE_SIZE 1    /* Executive size (7.25 x 10.5 inches) */
# define PCL_LETTER_SIZE    2    /* Letter size (8.5 x 11 inches) */
# define PCL_LEGAL_SIZE     3    /* Legal size (8.5 x 14 inches) */
# define PCL_A4_SIZE        26   /* A4 size (210 x 297 mm) */

# define PCL_LJ             10   /* Original LaserJet */
# define PCL_LJPLUS         11   /* LaserJet + */
# define PCL_LJ500          12   /* LaserJet 500 + */
# define PCL_LJ2            20   /* LaserJet II */
# define PCL_LJ2P           21   /* LaserJet IIp */
# define PCL_LJ3            30   /* LaserJet III series */
# define PCL_LJ4            40   /* LaserJet 4 series */
# define PCL_DJ500          500  /* DeskJet 500 */
# define PCL_DJ500C         501  /* DeskJet 500c (color) */
# define PCL_DJ550          550  /* DeskJet 550 */
# define PCL_DJ550C         551  /* DeskJet 550c (color) */
# define PCL_DJ1200C        1201 /* DeskJet 1200c (color) */


/*
 * Defaults...
 */

# define DEFAULT_TYPE      PCL_AUTO
# define DEFAULT_MODE      PCL_AUTO
# define DEFAULT_DPI       PCL_AUTO
# define DEFAULT_MEDIA     PCL_PAPER
# define DEFAULT_ORIENT    PCL_AUTO
# define DEFAULT_FLIP      PCL_FLIP_NONE
# define DEFAULT_SOURCE    PCL_DEFAULT_TRAY
# define DEFAULT_SIZE      PCL_LETTER_SIZE
# define DEFAULT_MODEL     PCL_LJ2
# define DEFAULT_PAGES     "1x1"
# define DEFAULT_COPIES    1
# define DEFAULT_GAMMA     PCL_AUTO


/*
 * Globals...
 */

# ifdef _TOPCL_C_
#  define VAR
#  define VALUE(x) =x
# else
#  define VAR      extern
#  define VALUE(x)
# endif /* _TOPCL_C_ */

VAR int   OutputType      VALUE(DEFAULT_TYPE);   /* Color or BW output? */
VAR int   OutputMode      VALUE(DEFAULT_MODE);   /* Compression mode */
VAR int   OutputDpi       VALUE(DEFAULT_DPI);    /* Resolution */
VAR int   OutputMedia     VALUE(DEFAULT_MEDIA);  /* Paper/transparency */
VAR int   OutputOrient    VALUE(DEFAULT_ORIENT); /* Portrait/landscape */
VAR int   OutputFlip      VALUE(DEFAULT_FLIP);   /* Flip an axis or two? */
VAR char  *OutputPages    VALUE(DEFAULT_PAGES);  /* Number of pages/image */
VAR int   OutputCopies    VALUE(DEFAULT_COPIES); /* Number of copies */
VAR float OutputGamma     VALUE(DEFAULT_GAMMA);  /* Gamma correction */

VAR int   PaperSource     VALUE(DEFAULT_SOURCE); /* Source of media */
VAR int   PaperSize       VALUE(DEFAULT_SIZE);   /* Size of media */
VAR int   PaperWidth;                            /* Decipoint width */
VAR int   PaperHeight;                           /* Decipoint height */

VAR int   PrinterModel    VALUE(DEFAULT_MODEL);  /* Model of printer */

VAR PRINTER PrinterModels[]                      /* Model defaults */
#ifdef _TOPCL_C_
= { /*                                              letter       legal      executive      A4    */
    /* model,     type,      cmode,     dpi, copies, w,    h,    w,    h,     w,    h,    w,    h    */
   { PCL_LJ,      PCL_BW,    PCL_MODE0, 150, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 0,    0    },
   { PCL_LJPLUS,  PCL_BW,    PCL_MODE0, 150, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 0,    0    },
   { PCL_LJ500,   PCL_BW,    PCL_MODE0, 150, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 0,    0    },
   { PCL_LJ2,     PCL_BW,    PCL_MODE0, 300, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 5611, 7697 },
   { PCL_LJ2P,    PCL_BW,    PCL_MODE2, 300, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 5611, 7697 },
   { PCL_LJ3,     PCL_BW,    PCL_MODE3, 300, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 5611, 7697 },
   { PCL_LJ4,     PCL_BW,    PCL_MODE3, 600, TRUE,   5760, 7200, 5760, 9360,  4860, 6840, 5611, 7697 },
   { PCL_DJ500,   PCL_BW,    PCL_MODE3, 300, FALSE,  5760, 7020, 5760, 9180,  4860, 6660, 5611, 7517 },
   { PCL_DJ500C,  PCL_COLOR, PCL_MODE9, 300, FALSE,  5760, 7020, 5760, 9180,  4860, 6660, 5611, 7517 },
   { PCL_DJ550,   PCL_BW,    PCL_MODE3, 300, FALSE,  5760, 7020, 5760, 9180,  4860, 6660, 5611, 7517 },
   { PCL_DJ550C,  PCL_COLOR, PCL_MODE9, 300, FALSE,  5760, 7020, 5760, 9180,  4860, 6660, 5611, 7517 },
   { PCL_DJ1200C, PCL_COLOR, PCL_MODE9, 300, FALSE,  5760, 7020, 5760, 9180,  4860, 6660, 5611, 7517 }
  }
#endif /* _TOPCL_C_ */
;


/*
 * Prototypes...
 */

extern void      AdjustImage(RGB_IMAGE *i, float gamma);
extern RGB_IMAGE *AllocImage(int width, int height);
extern void      FreeImage(RGB_IMAGE *i);
extern void      GreyImage(RGB_IMAGE *i);
extern RGB_IMAGE *LoadImage(char *filename);
extern void      OutputImage(RGB_IMAGE *image, int left, int top,
                             int right, int bottom);


#endif /* _TOPCL_H_ */

/*
 * End of "$Id: topcl.h,v 1.4 93/12/05 10:44:08 mike Exp Locker: mike $".
 */

