.\"
.\" "$Id: topcl.man,v 1.2 93/12/05 10:52:27 mike Exp Locker: mike $"
.\"
.\" Manual page for TOPCL, an SGI image to PCL converter.
.\"
.\" Copyright (c) 1993 Easy Software Products
.\"                    P.O. Box 256
.\"                    Park Hall, MD  20667
.\"                    Attn: Michael Sweet (dodgecolt@delphi.com)
.\"
.\" This file is part of TOPCL.
.\"
.\" TOPCL is distributed in the hope that it will be useful, but
.\" WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
.\" to anyone for the consequences of using it or for whether it serves any
.\" particular purpose or works at all, unless he says so in writing.  Refer
.\" to the TOPCL General Public License for full details.
.\"
.\" Everyone is granted permission to copy, modify and redistribute
.\" TOPCL, but only under the conditions described in the TOPCL
.\" General Public License.  A copy of this license is supposed to have been
.\" given to you along with TOPCL so you can know your rights and
.\" responsibilities.  It should be in a file named COPYING.  Among other
.\" things, the copyright notice and this notice must be preserved on all
.\" copies.
.\"
.\" Revision History:
.\"
.\"  $Log:	topcl.man,v $
.\" Revision 1.2  93/12/05  10:52:27  mike
.\" Updated documentation for v1.1 release.
.\" 
.\" Revision 1.1  93/06/10  22:35:17  mike
.\" Initial revision
.\" 
.\"
.TH TOPCL 1 "Printer Utilities" "5 December 1993" "Easy Software Products"
.SH NAME
topcl \- convert an iris image to page control language (pcl)
.sp
.SH SYNOPSIS
.nf
\fBtopcl inimage\fR	[-model \fImodel-name\fR]
		[-bw] [-color]
		[-compmode \fImode\fR]
		[-dpi \fIresolution\fR]
		[-copies \fInumber-copies\fR]
		[-size \fIpaper-size\fR]
		[-media \fImedia-type\fR]
		[-source \fIpaper-source\fR]
		[-portrait] [-landscape]
		[-pages \fInumber-pages\fR]
		[-flip \fIaxis\fR]
		[-gamma \fIgamma-value\fR]
.fi
.sp
.SH DESCRIPTION
\fItopcl\fR converts an IRIS image file into Page Control Language (PCL) data
suitable for output to a variety of Hewlett-Packard compatible laser and
inkjet printers.  This program can generate black and white or color PCL.
Output is dithered to produce the appearance of grey shades or continuous-tone
color.  Option names and parameters may be abbreviated as long as enough
letters are specified to distinguish between names.
.sp
The \fI-model\fR option specifies the model of the destination printer.  The
following models are presently recognized:
.sp
.nf
.in +.5i
lj	Original LaserJet
lj+	LaserJet Plus
lj500	LaserJet 500
lj2	LaserJet II (default)
lj2p	LaserJet IIp
lj3	LaserJet III series
lj4	LaserJet 4 series
dj500	DeskJet 500
dj500c	DeskJet 500C (color)
dj550	DeskJet 550
dj550c	DeskJet 550C (color)
dj1200c	DeskJet 1200C (color)
.in
.fi
.sp
The \fI-bw\fR option specifies the output should be in black and white.  The
\fI-color\fR option specifies the output should be in color.
.sp
The \fI-compmode\fR option specifies the highest level of compression to be
used for the output; the actual compression used is chosen to produce the
smallest output size possible.  The compression level may range from 0 to 3
or 9 (for DeskJet printers), where 0 corresponds to no compression.  Note that
some PCL printers do not support all levels of compression!  Use of the
\fI-model\fR option is strongly encouraged as it sets the highest level of
compression available for a specific printer.
.sp
The \fI-dpi\fR option specifies the output resolution in dots-per-inch.
Acceptable values are 75, 100, 150, 300, and 600 (LaserJet 4 only).  Output
resolution is limited on LaserJets by the available RAM on the printer.  The
default is chosen based upon the model of printer selected:
.sp
.nf
.in +.5i
LaserJet		150
LaserJet Plus	150
LaserJet 500	150
LaserJet II	300
LaserJet IIp	300
LaserJet III series	300
LaserJet 4 series	600
DeskJet series	300
.in
.fi
.sp
The \fI-copies\fR option causes the generation of additional copies by the
printer.  In general, this is more efficient than using the \fIlp(1)\fR or
\fIlpr(1)\fR copy mechanism.  Since the DeskJet series of printers does not
support multiple-copy generation, multiple copies of each page are generated
manually.  The default is single copy output.
.sp
The \fI-size\fR option specifies the size of the output page.  Acceptable
sizes are \fIletter, legal, executive,\fR and \fIa4\fR.  The default is letter
size output.
.sp
The \fI-media\fR option specifies the type of output media.  Acceptable media
are \fIpaper\fR and \fItransparency\fR.  The default is paper media.
.sp
The \fI-source\fR option specifies the media source.  Acceptable sources are
\fIupper, lower,\fR and \fImanual\fR.  If not specified, the printer default
source is used.
.sp
The \fI-portrait\fR and \fI-landscape\fR options specify the output
orientation.  If not specified, the output is oriented to fill the largest
area of the page.
.sp
The \fI-pages\fR option specifies the number of output pages to produce for an
image.  This can be expressed as \fIN\fR or \fINxM\fR.  Output is suitable for
pasting together for posters or other large displays.
.sp
The \fI-flip\fR option causes one or both axis to be flipped on output.
Acceptable axis names are \fIx, y,\fR and \fIxy\fR.  Axis are specified
according to the original image and not to the page.
.sp
The \fI-gamma\fR option specifies the amount of gamma correction to apply to
the image before output.  If not specified, the current system gamma level is
used.
.sp
.SH EXAMPLES
To print an image file called \fIbullwinkle.rgb\fR to a LaserJet III printer:
.sp
.nf
.in +.5i
topcl bullwinkle.rgb -model lj3 | lp -oraw
.in
.fi
.sp
To print an image file called \fIboris.rgb\fR to a DeskJet 500c printer with
three pages across and two pages tall:
.sp
.nf
.in +.5i
topcl boris.rgb -model dj500c -pages 3x2 | lp -oraw
.in
.fi
.sp
.SH BUGS
Presently, only RGB and black-and-white image formats are supported.
The PaintJet-series of PCL printers is not supported.
.sp
.SH SEE ALSO
ipaste (1G), snapshot(6D)
.sp
.SH AUTHOR
Michael Sweet (dodgecolt@delphi.com), Easy Software Products
.\"
.\" End of "$Id: topcl.man,v 1.2 93/12/05 10:52:27 mike Exp Locker: mike $".
.\"

